# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SharedItemInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'shared_topics': 'int',
        'shared_users': 'int',
        'shared_workbooks': 'int'
    }

    attribute_map = {
        'shared_topics': 'sharedTopics',
        'shared_users': 'sharedUsers',
        'shared_workbooks': 'sharedWorkbooks'
    }

    def __init__(self, shared_topics=None, shared_users=None, shared_workbooks=None):
        """
        SharedItemInformation - a model defined in Swagger
        """

        self._shared_topics = None
        self._shared_users = None
        self._shared_workbooks = None

        if shared_topics is not None:
          self.shared_topics = shared_topics
        if shared_users is not None:
          self.shared_users = shared_users
        if shared_workbooks is not None:
          self.shared_workbooks = shared_workbooks

    @property
    def shared_topics(self):
        """
        Gets the shared_topics of this SharedItemInformation.
        The number of topics shared

        :return: The shared_topics of this SharedItemInformation.
        :rtype: int
        """
        return self._shared_topics

    @shared_topics.setter
    def shared_topics(self, shared_topics):
        """
        Sets the shared_topics of this SharedItemInformation.
        The number of topics shared

        :param shared_topics: The shared_topics of this SharedItemInformation.
        :type: int
        """

        self._shared_topics = shared_topics

    @property
    def shared_users(self):
        """
        Gets the shared_users of this SharedItemInformation.
        The number of users shared

        :return: The shared_users of this SharedItemInformation.
        :rtype: int
        """
        return self._shared_users

    @shared_users.setter
    def shared_users(self, shared_users):
        """
        Sets the shared_users of this SharedItemInformation.
        The number of users shared

        :param shared_users: The shared_users of this SharedItemInformation.
        :type: int
        """

        self._shared_users = shared_users

    @property
    def shared_workbooks(self):
        """
        Gets the shared_workbooks of this SharedItemInformation.
        The number of workbooks shared

        :return: The shared_workbooks of this SharedItemInformation.
        :rtype: int
        """
        return self._shared_workbooks

    @shared_workbooks.setter
    def shared_workbooks(self, shared_workbooks):
        """
        Sets the shared_workbooks of this SharedItemInformation.
        The number of workbooks shared

        :param shared_workbooks: The shared_workbooks of this SharedItemInformation.
        :type: int
        """

        self._shared_workbooks = shared_workbooks

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SharedItemInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
