# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemFinderInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cron_schedule': 'list[str]',
        'description': 'str',
        'enabled': 'bool',
        'fixed_list_searches': 'list[FixedListSearchV1]',
        'hierarchy_searches': 'list[HierarchySearchV1]',
        'include_hierarchy': 'bool',
        'name': 'str',
        'property_searches': 'list[PropertySearchV1]',
        'scaling_table_uuid_column_searches': 'list[ScalingTableUUIDColumnSearchV1]',
        'scoped_to': 'str',
        'searches': 'list[SwapAcrossAssetsSearchV1]',
        'skip_job_scheduling': 'bool',
        'stored_table_searches': 'list[StoredTableSearchV1]',
        'timezone': 'str'
    }

    attribute_map = {
        'cron_schedule': 'cronSchedule',
        'description': 'description',
        'enabled': 'enabled',
        'fixed_list_searches': 'fixedListSearches',
        'hierarchy_searches': 'hierarchySearches',
        'include_hierarchy': 'includeHierarchy',
        'name': 'name',
        'property_searches': 'propertySearches',
        'scaling_table_uuid_column_searches': 'scalingTableUUIDColumnSearches',
        'scoped_to': 'scopedTo',
        'searches': 'searches',
        'skip_job_scheduling': 'skipJobScheduling',
        'stored_table_searches': 'storedTableSearches',
        'timezone': 'timezone'
    }

    def __init__(self, cron_schedule=None, description=None, enabled=True, fixed_list_searches=None, hierarchy_searches=None, include_hierarchy=False, name=None, property_searches=None, scaling_table_uuid_column_searches=None, scoped_to=None, searches=None, skip_job_scheduling=False, stored_table_searches=None, timezone=None):
        """
        ItemFinderInputV1 - a model defined in Swagger
        """

        self._cron_schedule = None
        self._description = None
        self._enabled = None
        self._fixed_list_searches = None
        self._hierarchy_searches = None
        self._include_hierarchy = None
        self._name = None
        self._property_searches = None
        self._scaling_table_uuid_column_searches = None
        self._scoped_to = None
        self._searches = None
        self._skip_job_scheduling = None
        self._stored_table_searches = None
        self._timezone = None

        if cron_schedule is not None:
          self.cron_schedule = cron_schedule
        if description is not None:
          self.description = description
        if enabled is not None:
          self.enabled = enabled
        if fixed_list_searches is not None:
          self.fixed_list_searches = fixed_list_searches
        if hierarchy_searches is not None:
          self.hierarchy_searches = hierarchy_searches
        if include_hierarchy is not None:
          self.include_hierarchy = include_hierarchy
        if name is not None:
          self.name = name
        if property_searches is not None:
          self.property_searches = property_searches
        if scaling_table_uuid_column_searches is not None:
          self.scaling_table_uuid_column_searches = scaling_table_uuid_column_searches
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if searches is not None:
          self.searches = searches
        if skip_job_scheduling is not None:
          self.skip_job_scheduling = skip_job_scheduling
        if stored_table_searches is not None:
          self.stored_table_searches = stored_table_searches
        if timezone is not None:
          self.timezone = timezone

    @property
    def cron_schedule(self):
        """
        Gets the cron_schedule of this ItemFinderInputV1.
        The item finder's check interval(s) as a list of cron expressions. If the list is empty, the system wide default check schedule is used. For more information about cron expressions, see  http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html

        :return: The cron_schedule of this ItemFinderInputV1.
        :rtype: list[str]
        """
        return self._cron_schedule

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule):
        """
        Sets the cron_schedule of this ItemFinderInputV1.
        The item finder's check interval(s) as a list of cron expressions. If the list is empty, the system wide default check schedule is used. For more information about cron expressions, see  http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html

        :param cron_schedule: The cron_schedule of this ItemFinderInputV1.
        :type: list[str]
        """

        self._cron_schedule = cron_schedule

    @property
    def description(self):
        """
        Gets the description of this ItemFinderInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :return: The description of this ItemFinderInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ItemFinderInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :param description: The description of this ItemFinderInputV1.
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """
        Gets the enabled of this ItemFinderInputV1.
        Whether the item finder is enabled

        :return: The enabled of this ItemFinderInputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ItemFinderInputV1.
        Whether the item finder is enabled

        :param enabled: The enabled of this ItemFinderInputV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def fixed_list_searches(self):
        """
        Gets the fixed_list_searches of this ItemFinderInputV1.
        The list of searches containing a list of item IDs to always include or exclude in the output

        :return: The fixed_list_searches of this ItemFinderInputV1.
        :rtype: list[FixedListSearchV1]
        """
        return self._fixed_list_searches

    @fixed_list_searches.setter
    def fixed_list_searches(self, fixed_list_searches):
        """
        Sets the fixed_list_searches of this ItemFinderInputV1.
        The list of searches containing a list of item IDs to always include or exclude in the output

        :param fixed_list_searches: The fixed_list_searches of this ItemFinderInputV1.
        :type: list[FixedListSearchV1]
        """

        self._fixed_list_searches = fixed_list_searches

    @property
    def hierarchy_searches(self):
        """
        Gets the hierarchy_searches of this ItemFinderInputV1.
        The list of searches for finding hierarchy nodes based on item hierarchies. This search can only be used if includeHierarchy is true.

        :return: The hierarchy_searches of this ItemFinderInputV1.
        :rtype: list[HierarchySearchV1]
        """
        return self._hierarchy_searches

    @hierarchy_searches.setter
    def hierarchy_searches(self, hierarchy_searches):
        """
        Sets the hierarchy_searches of this ItemFinderInputV1.
        The list of searches for finding hierarchy nodes based on item hierarchies. This search can only be used if includeHierarchy is true.

        :param hierarchy_searches: The hierarchy_searches of this ItemFinderInputV1.
        :type: list[HierarchySearchV1]
        """

        self._hierarchy_searches = hierarchy_searches

    @property
    def include_hierarchy(self):
        """
        Gets the include_hierarchy of this ItemFinderInputV1.
        Whether the item finder will include hierarchy information

        :return: The include_hierarchy of this ItemFinderInputV1.
        :rtype: bool
        """
        return self._include_hierarchy

    @include_hierarchy.setter
    def include_hierarchy(self, include_hierarchy):
        """
        Sets the include_hierarchy of this ItemFinderInputV1.
        Whether the item finder will include hierarchy information

        :param include_hierarchy: The include_hierarchy of this ItemFinderInputV1.
        :type: bool
        """

        self._include_hierarchy = include_hierarchy

    @property
    def name(self):
        """
        Gets the name of this ItemFinderInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :return: The name of this ItemFinderInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ItemFinderInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this ItemFinderInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def property_searches(self):
        """
        Gets the property_searches of this ItemFinderInputV1.
        The list of searches based on properties

        :return: The property_searches of this ItemFinderInputV1.
        :rtype: list[PropertySearchV1]
        """
        return self._property_searches

    @property_searches.setter
    def property_searches(self, property_searches):
        """
        Sets the property_searches of this ItemFinderInputV1.
        The list of searches based on properties

        :param property_searches: The property_searches of this ItemFinderInputV1.
        :type: list[PropertySearchV1]
        """

        self._property_searches = property_searches

    @property
    def scaling_table_uuid_column_searches(self):
        """
        Gets the scaling_table_uuid_column_searches of this ItemFinderInputV1.
        The list of searches for finding items based on a materialized table's UUID column

        :return: The scaling_table_uuid_column_searches of this ItemFinderInputV1.
        :rtype: list[ScalingTableUUIDColumnSearchV1]
        """
        return self._scaling_table_uuid_column_searches

    @scaling_table_uuid_column_searches.setter
    def scaling_table_uuid_column_searches(self, scaling_table_uuid_column_searches):
        """
        Sets the scaling_table_uuid_column_searches of this ItemFinderInputV1.
        The list of searches for finding items based on a materialized table's UUID column

        :param scaling_table_uuid_column_searches: The scaling_table_uuid_column_searches of this ItemFinderInputV1.
        :type: list[ScalingTableUUIDColumnSearchV1]
        """

        self._scaling_table_uuid_column_searches = scaling_table_uuid_column_searches

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ItemFinderInputV1.
        The ID of the workbook to which the item finder will be scoped. If not provided, it will have a global scope

        :return: The scoped_to of this ItemFinderInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ItemFinderInputV1.
        The ID of the workbook to which the item finder will be scoped. If not provided, it will have a global scope

        :param scoped_to: The scoped_to of this ItemFinderInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def searches(self):
        """
        Gets the searches of this ItemFinderInputV1.
        The list of searches for swapping across assets to find items

        :return: The searches of this ItemFinderInputV1.
        :rtype: list[SwapAcrossAssetsSearchV1]
        """
        return self._searches

    @searches.setter
    def searches(self, searches):
        """
        Sets the searches of this ItemFinderInputV1.
        The list of searches for swapping across assets to find items

        :param searches: The searches of this ItemFinderInputV1.
        :type: list[SwapAcrossAssetsSearchV1]
        """

        self._searches = searches

    @property
    def skip_job_scheduling(self):
        """
        Gets the skip_job_scheduling of this ItemFinderInputV1.
        If true, the Item Finder job will not be scheduled. Typically used when executing searches immediately upon creation. Cannot be true if a cron schedule is provided, as those options are mutually exclusive. Set this to true any time the job should not be scheduled when updating or creating an Item Finder

        :return: The skip_job_scheduling of this ItemFinderInputV1.
        :rtype: bool
        """
        return self._skip_job_scheduling

    @skip_job_scheduling.setter
    def skip_job_scheduling(self, skip_job_scheduling):
        """
        Sets the skip_job_scheduling of this ItemFinderInputV1.
        If true, the Item Finder job will not be scheduled. Typically used when executing searches immediately upon creation. Cannot be true if a cron schedule is provided, as those options are mutually exclusive. Set this to true any time the job should not be scheduled when updating or creating an Item Finder

        :param skip_job_scheduling: The skip_job_scheduling of this ItemFinderInputV1.
        :type: bool
        """

        self._skip_job_scheduling = skip_job_scheduling

    @property
    def stored_table_searches(self):
        """
        Gets the stored_table_searches of this ItemFinderInputV1.
        The list of searches based on stored table values and properties

        :return: The stored_table_searches of this ItemFinderInputV1.
        :rtype: list[StoredTableSearchV1]
        """
        return self._stored_table_searches

    @stored_table_searches.setter
    def stored_table_searches(self, stored_table_searches):
        """
        Sets the stored_table_searches of this ItemFinderInputV1.
        The list of searches based on stored table values and properties

        :param stored_table_searches: The stored_table_searches of this ItemFinderInputV1.
        :type: list[StoredTableSearchV1]
        """

        self._stored_table_searches = stored_table_searches

    @property
    def timezone(self):
        """
        Gets the timezone of this ItemFinderInputV1.
        The IANA timezone in which the scheduled times will be run, defaults to UTC

        :return: The timezone of this ItemFinderInputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this ItemFinderInputV1.
        The IANA timezone in which the scheduled times will be run, defaults to UTC

        :param timezone: The timezone of this ItemFinderInputV1.
        :type: str
        """

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemFinderInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
