# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class JoinInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'left_column_definition_id': 'str',
        'right': 'str',
        'right_column_definition_id': 'str',
        'type': 'str'
    }

    attribute_map = {
        'left_column_definition_id': 'leftColumnDefinitionId',
        'right': 'right',
        'right_column_definition_id': 'rightColumnDefinitionId',
        'type': 'type'
    }

    def __init__(self, left_column_definition_id=None, right=None, right_column_definition_id=None, type=None):
        """
        JoinInputV1 - a model defined in Swagger
        """

        self._left_column_definition_id = None
        self._right = None
        self._right_column_definition_id = None
        self._type = None

        if left_column_definition_id is not None:
          self.left_column_definition_id = left_column_definition_id
        if right is not None:
          self.right = right
        if right_column_definition_id is not None:
          self.right_column_definition_id = right_column_definition_id
        if type is not None:
          self.type = type

    @property
    def left_column_definition_id(self):
        """
        Gets the left_column_definition_id of this JoinInputV1.
        Column definition ID from the left table

        :return: The left_column_definition_id of this JoinInputV1.
        :rtype: str
        """
        return self._left_column_definition_id

    @left_column_definition_id.setter
    def left_column_definition_id(self, left_column_definition_id):
        """
        Sets the left_column_definition_id of this JoinInputV1.
        Column definition ID from the left table

        :param left_column_definition_id: The left_column_definition_id of this JoinInputV1.
        :type: str
        """
        if left_column_definition_id is None:
            raise ValueError("Invalid value for `left_column_definition_id`, must not be `None`")

        self._left_column_definition_id = left_column_definition_id

    @property
    def right(self):
        """
        Gets the right of this JoinInputV1.
        Right side table source for the join

        :return: The right of this JoinInputV1.
        :rtype: str
        """
        return self._right

    @right.setter
    def right(self, right):
        """
        Sets the right of this JoinInputV1.
        Right side table source for the join

        :param right: The right of this JoinInputV1.
        :type: str
        """
        if right is None:
            raise ValueError("Invalid value for `right`, must not be `None`")

        self._right = right

    @property
    def right_column_definition_id(self):
        """
        Gets the right_column_definition_id of this JoinInputV1.
        Column definition ID from the right table

        :return: The right_column_definition_id of this JoinInputV1.
        :rtype: str
        """
        return self._right_column_definition_id

    @right_column_definition_id.setter
    def right_column_definition_id(self, right_column_definition_id):
        """
        Sets the right_column_definition_id of this JoinInputV1.
        Column definition ID from the right table

        :param right_column_definition_id: The right_column_definition_id of this JoinInputV1.
        :type: str
        """
        if right_column_definition_id is None:
            raise ValueError("Invalid value for `right_column_definition_id`, must not be `None`")

        self._right_column_definition_id = right_column_definition_id

    @property
    def type(self):
        """
        Gets the type of this JoinInputV1.
        Type of join

        :return: The type of this JoinInputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this JoinInputV1.
        Type of join

        :param type: The type of this JoinInputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, JoinInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
