# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelFormulaCreatorRuleV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'ModelRuleInputV1String',
        'formula': 'ModelRuleInputV1String',
        'identity_id': 'ModelRuleInputV1UUID',
        'name': 'ModelRuleInputV1String',
        'parameters': 'ModelRuleInputV1ListString',
        'permission_string': 'ModelRuleInputV1String',
        'scoped_to': 'ModelRuleInputV1UUID',
        'variable_parameter_strings': 'ModelRuleInputV1ListString',
        'variable_parameters': 'ModelRuleInputV1ListString'
    }

    attribute_map = {
        'description': 'description',
        'formula': 'formula',
        'identity_id': 'identityId',
        'name': 'name',
        'parameters': 'parameters',
        'permission_string': 'permissionString',
        'scoped_to': 'scopedTo',
        'variable_parameter_strings': 'variableParameterStrings',
        'variable_parameters': 'variableParameters'
    }

    def __init__(self, description=None, formula=None, identity_id=None, name=None, parameters=None, permission_string=None, scoped_to=None, variable_parameter_strings=None, variable_parameters=None):
        """
        ModelFormulaCreatorRuleV1 - a model defined in Swagger
        """

        self._description = None
        self._formula = None
        self._identity_id = None
        self._name = None
        self._parameters = None
        self._permission_string = None
        self._scoped_to = None
        self._variable_parameter_strings = None
        self._variable_parameters = None

        if description is not None:
          self.description = description
        if formula is not None:
          self.formula = formula
        if identity_id is not None:
          self.identity_id = identity_id
        if name is not None:
          self.name = name
        if parameters is not None:
          self.parameters = parameters
        if permission_string is not None:
          self.permission_string = permission_string
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if variable_parameter_strings is not None:
          self.variable_parameter_strings = variable_parameter_strings
        if variable_parameters is not None:
          self.variable_parameters = variable_parameters

    @property
    def description(self):
        """
        Gets the description of this ModelFormulaCreatorRuleV1.

        :return: The description of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1String
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ModelFormulaCreatorRuleV1.

        :param description: The description of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1String
        """

        self._description = description

    @property
    def formula(self):
        """
        Gets the formula of this ModelFormulaCreatorRuleV1.

        :return: The formula of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1String
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """
        Sets the formula of this ModelFormulaCreatorRuleV1.

        :param formula: The formula of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1String
        """
        if formula is None:
            raise ValueError("Invalid value for `formula`, must not be `None`")

        self._formula = formula

    @property
    def identity_id(self):
        """
        Gets the identity_id of this ModelFormulaCreatorRuleV1.

        :return: The identity_id of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1UUID
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this ModelFormulaCreatorRuleV1.

        :param identity_id: The identity_id of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1UUID
        """

        self._identity_id = identity_id

    @property
    def name(self):
        """
        Gets the name of this ModelFormulaCreatorRuleV1.

        :return: The name of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1String
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ModelFormulaCreatorRuleV1.

        :param name: The name of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1String
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def parameters(self):
        """
        Gets the parameters of this ModelFormulaCreatorRuleV1.

        :return: The parameters of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1ListString
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this ModelFormulaCreatorRuleV1.

        :param parameters: The parameters of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1ListString
        """
        if parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")

        self._parameters = parameters

    @property
    def permission_string(self):
        """
        Gets the permission_string of this ModelFormulaCreatorRuleV1.

        :return: The permission_string of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1String
        """
        return self._permission_string

    @permission_string.setter
    def permission_string(self, permission_string):
        """
        Sets the permission_string of this ModelFormulaCreatorRuleV1.

        :param permission_string: The permission_string of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1String
        """

        self._permission_string = permission_string

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ModelFormulaCreatorRuleV1.

        :return: The scoped_to of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1UUID
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ModelFormulaCreatorRuleV1.

        :param scoped_to: The scoped_to of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1UUID
        """

        self._scoped_to = scoped_to

    @property
    def variable_parameter_strings(self):
        """
        Gets the variable_parameter_strings of this ModelFormulaCreatorRuleV1.

        :return: The variable_parameter_strings of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1ListString
        """
        return self._variable_parameter_strings

    @variable_parameter_strings.setter
    def variable_parameter_strings(self, variable_parameter_strings):
        """
        Sets the variable_parameter_strings of this ModelFormulaCreatorRuleV1.

        :param variable_parameter_strings: The variable_parameter_strings of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1ListString
        """

        self._variable_parameter_strings = variable_parameter_strings

    @property
    def variable_parameters(self):
        """
        Gets the variable_parameters of this ModelFormulaCreatorRuleV1.

        :return: The variable_parameters of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1ListString
        """
        return self._variable_parameters

    @variable_parameters.setter
    def variable_parameters(self, variable_parameters):
        """
        Sets the variable_parameters of this ModelFormulaCreatorRuleV1.

        :param variable_parameters: The variable_parameters of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1ListString
        """

        self._variable_parameters = variable_parameters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelFormulaCreatorRuleV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
